@@ -16,13 +16,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Wrapper for the GitLab API."""
 
-from __future__ import print_function
-from __future__ import absolute_import
 import importlib
 import time
 import warnings
 
 import requests
+import requests.utils
 
 import gitlab.config
 from gitlab.const import *  # noqa
@@ -30,7 +29,7 @@ from gitlab.exceptions import *  # noqa
 from gitlab import utils  # noqa
 
 __title__ = "python-gitlab"
-__version__ = "2.1.2"
+__version__ = "2.4.0"
 __author__ = "Gauvain Pocentek"
 __email__ = "gauvainpocentek@gmail.com"
 __license__ = "LGPL3"
@@ -43,6 +42,8 @@ REDIRECT_MSG = (
     "must update your GitLab URL to use https:// to avoid issues."
 )
 
+ALLOWED_KEYSET_ENDPOINTS = ["/projects"]
+
 
 def _sanitize(value):
     if isinstance(value, dict):
@@ -119,6 +120,7 @@ class Gitlab(object):
 
         self.broadcastmessages = objects.BroadcastMessageManager(self)
         self.deploykeys = objects.DeployKeyManager(self)
+        self.deploytokens = objects.DeployTokenManager(self)
         self.geonodes = objects.GeoNodeManager(self)
         self.gitlabciymls = objects.GitlabciymlManager(self)
         self.gitignores = objects.GitignoreManager(self)
@@ -605,10 +607,10 @@ class Gitlab(object):
         ):
             try:
                 return result.json()
-            except Exception:
+            except Exception as e:
                 raise GitlabParsingError(
                     error_message="Failed to parse the server message"
-                )
+                ) from e
         else:
             return result
 
@@ -617,7 +619,7 @@ class Gitlab(object):
 
         Args:
             path (str): Path or full URL to query ('/projects' or
-                        'http://whatever/v4/api/projecs')
+                        'http://whatever/v4/api/projects')
             query_data (dict): Data to send as query parameters
             **kwargs: Extra options to send to the server (e.g. sudo, page,
                       per_page)
@@ -641,10 +643,12 @@ class Gitlab(object):
         get_all = kwargs.pop("all", False)
         url = self._build_url(path)
 
+        page = kwargs.get("page")
+
         if get_all is True and as_list is True:
             return list(GitlabList(self, url, query_data, **kwargs))
 
-        if "page" in kwargs or as_list is True:
+        if page or as_list is True:
             # pagination requested, we return a list
             return list(GitlabList(self, url, query_data, get_next=False, **kwargs))
 
@@ -685,8 +689,10 @@ class Gitlab(object):
         try:
             if result.headers.get("Content-Type", None) == "application/json":
                 return result.json()
-        except Exception:
-            raise GitlabParsingError(error_message="Failed to parse the server message")
+        except Exception as e:
+            raise GitlabParsingError(
+                error_message="Failed to parse the server message"
+            ) from e
         return result
 
     def http_put(self, path, query_data=None, post_data=None, files=None, **kwargs):
@@ -721,8 +727,10 @@ class Gitlab(object):
         )
         try:
             return result.json()
-        except Exception:
-            raise GitlabParsingError(error_message="Failed to parse the server message")
+        except Exception as e:
+            raise GitlabParsingError(
+                error_message="Failed to parse the server message"
+            ) from e
 
     def http_delete(self, path, **kwargs):
         """Make a PUT request to the Gitlab server.
@@ -769,14 +777,25 @@ class GitlabList(object):
 
     def __init__(self, gl, url, query_data, get_next=True, **kwargs):
         self._gl = gl
-        self._query(url, query_data, **kwargs)
+
+        # Preserve kwargs for subsequent queries
+        self._kwargs = kwargs.copy()
+
+        self._query(url, query_data, **self._kwargs)
         self._get_next = get_next
 
     def _query(self, url, query_data=None, **kwargs):
         query_data = query_data or {}
         result = self._gl.http_request("get", url, query_data=query_data, **kwargs)
         try:
-            self._next_url = result.links["next"]["url"]
+            links = result.links
+            if links:
+                next_url = links["next"]["url"]
+            else:
+                next_url = requests.utils.parse_header_links(result.headers["links"])[
+                    0
+                ]["url"]
+            self._next_url = next_url
         except KeyError:
             self._next_url = None
         self._current_page = result.headers.get("X-Page")
@@ -788,8 +807,10 @@ class GitlabList(object):
 
         try:
             self._data = result.json()
-        except Exception:
-            raise GitlabParsingError(error_message="Failed to parse the server message")
+        except Exception as e:
+            raise GitlabParsingError(
+                error_message="Failed to parse the server message"
+            ) from e
 
         self._current = 0
 
@@ -800,9 +821,9 @@ class GitlabList(object):
 
     @property
     def prev_page(self):
-        """The next page number.
+        """The previous page number.
 
-        If None, the current page is the last.
+        If None, the current page is the first.
         """
         return int(self._prev_page) if self._prev_page else None
 
@@ -847,7 +868,7 @@ class GitlabList(object):
             pass
 
         if self._next_url and self._get_next is True:
-            self._query(self._next_url)
+            self._query(self._next_url, **self._kwargs)
             return self.next()
 
         raise StopIteration
