@@ -626,23 +626,6 @@ class TestGitlab(unittest.TestCase):
             self.assertIsInstance(statistics, ProjectIssuesStatistics)
             self.assertEqual(statistics.statistics["counts"]["all"], 20)
 
-    def test_groups(self):
-        @urlmatch(
-            scheme="http", netloc="localhost", path="/api/v4/groups/1", method="get"
-        )
-        def resp_get_group(url, request):
-            headers = {"content-type": "application/json"}
-            content = '{"name": "name", "id": 1, "path": "path"}'
-            content = content.encode("utf-8")
-            return response(200, content, headers, None, 5, request)
-
-        with HTTMock(resp_get_group):
-            data = self.gl.groups.get(1)
-            self.assertIsInstance(data, Group)
-            self.assertEqual(data.name, "name")
-            self.assertEqual(data.path, "path")
-            self.assertEqual(data.id, 1)
-
     def test_issues(self):
         @urlmatch(
             scheme="http", netloc="localhost", path="/api/v4/issues", method="get"
@@ -843,50 +826,6 @@ class TestGitlab(unittest.TestCase):
             self.gl.users.get(1, lazy=True).activate()
             self.gl.users.get(1, lazy=True).deactivate()
 
-    def test_commit_revert(self):
-        @urlmatch(
-            scheme="http",
-            netloc="localhost",
-            path="/api/v4/projects/1/repository/commits/6b2257ea",
-            method="get",
-        )
-        def resp_get_commit(url, request):
-            headers = {"content-type": "application/json"}
-            content = """{
-            "id": "6b2257eabcec3db1f59dafbd84935e3caea04235",
-            "short_id": "6b2257ea",
-            "title": "Initial commit"
-            }"""
-            content = content.encode("utf-8")
-            return response(200, content, headers, None, 5, request)
-
-        @urlmatch(
-            scheme="http",
-            netloc="localhost",
-            path="/api/v4/projects/1/repository/commits/6b2257ea",
-            method="post",
-        )
-        def resp_revert_commit(url, request):
-            headers = {"content-type": "application/json"}
-            content = """{
-            "id": "8b090c1b79a14f2bd9e8a738f717824ff53aebad",
-            "short_id": "8b090c1b",
-            "title":"Revert \\"Initial commit\\""
-            }"""
-            content = content.encode("utf-8")
-            return response(200, content, headers, None, 5, request)
-
-        with HTTMock(resp_get_commit):
-            project = self.gl.projects.get(1, lazy=True)
-            commit = project.commits.get("6b2257ea")
-            self.assertEqual(commit.short_id, "6b2257ea")
-            self.assertEqual(commit.title, "Initial commit")
-
-        with HTTMock(resp_revert_commit):
-            revert_commit = commit.revert(branch="master")
-            self.assertEqual(revert_commit["short_id"], "8b090c1b")
-            self.assertEqual(revert_commit["title"], 'Revert "Initial commit"')
-
     def test_update_submodule(self):
         @urlmatch(
             scheme="http", netloc="localhost", path="/api/v4/projects/1$", method="get"
@@ -937,33 +876,6 @@ class TestGitlab(unittest.TestCase):
             self.assertEqual(ret["message"], "Message")
             self.assertEqual(ret["id"], "ed899a2f4b50b4370feeea94676502b42383c746")
 
-    def test_import_github(self):
-        @urlmatch(
-            scheme="http",
-            netloc="localhost",
-            path="/api/v4/import/github",
-            method="post",
-        )
-        def resp_import_github(url, request):
-            headers = {"content-type": "application/json"}
-            content = """{
-            "id": 27,
-            "name": "my-repo",
-            "full_path": "/root/my-repo",
-            "full_name": "Administrator / my-repo"
-            }"""
-            content = content.encode("utf-8")
-            return response(200, content, headers, None, 25, request)
-
-        with HTTMock(resp_import_github):
-            base_path = "/root"
-            name = "my-repo"
-            ret = self.gl.projects.import_github("githubkey", 1234, base_path, name)
-            self.assertIsInstance(ret, dict)
-            self.assertEqual(ret["name"], name)
-            self.assertEqual(ret["full_path"], "/".join((base_path, name)))
-            self.assertTrue(ret["full_name"].endswith(name))
-
     def test_applications(self):
         content = '{"name": "test_app", "redirect_uri": "http://localhost:8080", "scopes": ["api", "email"]}'
         json_content = json.loads(content)
@@ -991,6 +903,40 @@ class TestGitlab(unittest.TestCase):
             self.assertEqual(application.redirect_uri, "http://localhost:8080")
             self.assertEqual(application.scopes, ["api", "email"])
 
+    def test_deploy_tokens(self):
+        @urlmatch(
+            scheme="http",
+            netloc="localhost",
+            path="/api/v4/projects/1/deploy_tokens",
+            method="post",
+        )
+        def resp_deploy_token_create(url, request):
+            headers = {"content-type": "application/json"}
+            content = """{
+            "id": 1,
+            "name": "test_deploy_token",
+            "username": "custom-user",
+            "expires_at": "2022-01-01T00:00:00.000Z",
+            "token": "jMRvtPNxrn3crTAGukpZ",
+            "scopes": [ "read_repository" ]}"""
+            content = content.encode("utf-8")
+            return response(200, content, headers, None, 5, request)
+
+        with HTTMock(resp_deploy_token_create):
+            deploy_token = self.gl.projects.get(1, lazy=True).deploytokens.create(
+                {
+                    "name": "test_deploy_token",
+                    "expires_at": "2022-01-01T00:00:00.000Z",
+                    "username": "custom-user",
+                    "scopes": ["read_repository"],
+                }
+            )
+            self.assertIsInstance(deploy_token, ProjectDeployToken)
+            self.assertEqual(deploy_token.id, 1),
+            self.assertEqual(deploy_token.expires_at, "2022-01-01T00:00:00.000Z"),
+            self.assertEqual(deploy_token.username, "custom-user")
+            self.assertEqual(deploy_token.scopes, ["read_repository"])
+
     def _default_config(self):
         fd, temp_path = tempfile.mkstemp()
         os.write(fd, valid_config)
